AddressService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getAddress(
{required String provinceCode, required String municipalityCode, required String barangayCode}) → Future< Map< String, String?> > - Original method - Get complete address by codes
-
getBarangaysByMunicipality(
{required String provinceCode, required String municipalityCode}) → Future< List< Map< >String, dynamic> > - Get barangays by municipality code
-
getMunicipalitiesByProvince(
{required String provinceCode}) → Future< List< Map< >String, dynamic> > - Get municipalities by province code
-
getProvincesByRegion(
{required String regionSubCode}) → Future< List< Map< >String, dynamic> > - Get provinces by region subcode