PcicAddressService class
Offline helpers for PCIC RegionNo-based province, municipality, and
barangay cascades.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getAddress(
{required String regionNo, required String provinceCode, required String municipalityCode, required String barangayCode}) → Future< Map< String, String?> > - Returns a complete PCIC address for the given code set.
-
getBarangays(
{required String regionNo, required String provinceCode, required String municipalityCode, String? provinceId, String? municipalityId}) → Future< List< Map< >String, dynamic> > - Returns barangays for the selected PCIC municipality.
-
getMunicipalities(
{required String regionNo, required String provinceCode, String? provinceId}) → Future< List< Map< >String, dynamic> > - Returns municipalities for the selected PCIC province.
-
getProvinces(
{required String regionNo, String? regionOption}) → Future< List< Map< >String, dynamic> > -
Returns provinces for a PCIC
regionNo. -
getRegionNumbers(
) → Future< List< Map< >String, dynamic> > -
Returns the available PCIC
regionNovalues and any special region options, such as3A. -
getRegionOptions(
{required String regionNo}) → Future< List< Map< >String, dynamic> > -
Returns the selectable region options for a PCIC
regionNo.